==> haskell-file-embed-0.0.12.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-file-embed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 file-embed
version:              0.0.12.0
visibility:           public
id:                   file-embed-0.0.12.0-2N30h2jV55M9hEI1fjRZ9w
key:                  file-embed-0.0.12.0-2N30h2jV55M9hEI1fjRZ9w
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/snoyberg/file-embed
synopsis:             Use Template Haskell to embed file contents directly.
description:
    Use Template Haskell to read a file or all the files in a
    directory, and turn them into (path, bytestring) pairs
    embedded in your Haskell code.

category:             Data
abi:                  658f3dd482b508b5d500fdaef46d5347
exposed:              True
exposed-modules:      Data.FileEmbed
import-dirs:          /usr/lib/ghc-8.10.1/site-local/file-embed-0.0.12.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/file-embed-0.0.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/file-embed-0.0.12.0
hs-libraries:         HSfile-embed-0.0.12.0-2N30h2jV55M9hEI1fjRZ9w
depends:
    base-4.14.0.0 bytestring-0.10.10.0 directory-1.3.6.0
    filepath-1.4.2.1 template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-file-embed/html/file-embed.haddock
haddock-html:         /usr/share/doc/haskell-file-embed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-file-embed-0.0.12.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-file-embed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 file-embed
version:              0.0.12.0
visibility:           public
id:                   file-embed-0.0.12.0-6papwjxSf3GIbANOmbA0A8
key:                  file-embed-0.0.12.0-6papwjxSf3GIbANOmbA0A8
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/snoyberg/file-embed
synopsis:             Use Template Haskell to embed file contents directly.
description:
    Use Template Haskell to read a file or all the files in a
    directory, and turn them into (path, bytestring) pairs
    embedded in your Haskell code.

category:             Data
abi:                  17a403e7dd88fddc2e346e7156cb5c1e
exposed:              True
exposed-modules:      Data.FileEmbed
import-dirs:          /usr/lib/ghc-8.10.2/site-local/file-embed-0.0.12.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/file-embed-0.0.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/file-embed-0.0.12.0
hs-libraries:         HSfile-embed-0.0.12.0-6papwjxSf3GIbANOmbA0A8
depends:
    base-4.14.1.0 bytestring-0.10.10.0 directory-1.3.6.0
    filepath-1.4.2.1 template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-file-embed/html/file-embed.haddock
haddock-html:         /usr/share/doc/haskell-file-embed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
